﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

// from: https://www.youtube.com/watch?v=0HwZQt94uHQ

public class Fade : MonoBehaviour {

    public Texture2D fadeOutTexture;            // the texture that will overlay the screen.
    static float fadeSpeed = 0.8f;              // the fading speed, static so it persists across all scenes

    private int drawDepth = -1000;              // the texture's order int  he draw hierarchy: a low number means it renders on top
    private float alpha = 0.0f;                 // texture's alpha between 0 and 1
    private int fadeDir = -1;                   // the direction to fade: in = -1 or out = 1

    private void OnGUI()
    {
        // fade out/in the alpha value using a direction, a speed and Time.deltaTime to convert the operation to seconds
        alpha += fadeDir * fadeSpeed * Time.deltaTime;
        // force (clamp) the number between 0 and 1 because GUI.color uses alpha values between 0 and 1
        alpha = Mathf.Clamp01(alpha);

        // set color of our GUI (in this case our texture). All color values remain the same and the Alpha is set to the alpha variable
        GUI.color = new Color(GUI.color.r, GUI.color.g, GUI.color.b, alpha);            // set the alpha variable
        GUI.depth = drawDepth;                                                          // make the black texture render on top (drawn last)
        GUI.DrawTexture(new Rect(0, 0, Screen.width, Screen.height), fadeOutTexture);   // draw the texture to fit the entire screen area
    }
    // sets fadeDir to the direction parameter making hte scene fade in if -1 and out if 1
    public float BeginFade (int direction) {
        fadeDir = direction;
        return (fadeSpeed);         // return the fadeSpeed variable so it's easy to time the Application.LoadLevel();
    }

    // Called when a level is loaded.
    private void OnEnable() {//int level) {
        //alpha = 1.0f;        // use this if the alpha is not set
        //BeginFade(-1);

        SceneManager.sceneLoaded += OnLevelFinishedLoaded;
    }

    private void OnLevelFinishedLoaded(Scene scene, LoadSceneMode mode)
    {
        alpha = 1.0f;        // use this if the alpha is not set
        BeginFade(-1);
    }
}
